@@ -1,8 +1,13 @@
 from json import loads
-from os import path
-from sys import argv
+import os
+import sys
 
-print(path.dirname(path.realpath(argv[0])))
+print("1" + os.path.dirname(os.path.realpath(__file__)))
+print("2" + sys.path[0])
+print("3" + os.path.dirname(os.path.realpath(sys.argv[0])))
+print("4" + os.path.dirname(__file__))
+print("5" + os.path.realpath(__file__))
+print("6" + os.path.abspath(os.path.dirname(__file__)))
 
 def nori(args):
     verb = None
